using System;
using UnityEngine;
using System.Collections;
using System.Collections.Generic;
using SimpleJSON;

namespace Feel
{
    public class CustomScooterHelmet : MVRScript
    {
        #region Vars  

        private int _initLoops = 0;
        private int _maxInitLoops = 1000;

        protected JSONStorableBool IsShowStrap;

        public Transform ObjectRoot;
        public Transform StrapObj;

        #endregion

        public override void Init()
        {
            try
            {
                if (containingAtom.type != "CustomUnityAsset")
                {
                    SuperController.LogError("CustomScooter - Please add this script on a Custom Unity Asset ( script disabled).");
                    return;
                }

                _initLoops = 0;

                IsShowStrap = new JSONStorableBool("IsShowStrap", true, OnIsShowStrap);
                RegisterBool(IsShowStrap);
                UIDynamicToggle boostertoggle = CreateToggle(IsShowStrap, false);
                boostertoggle.label = "Strap On Off";

                // A tiny bit of help to give some info to your fellow creator and/or player
                JSONStorableString helpText = new JSONStorableString("About",
                    "<color=#000><size=35><b>Custom Scooter Helmet</b></size></color>\n\n" +
                    "<color=#333>" +
                    "store the position of the target,\n" +
                    "or Track a specific target.\n\n" +
                    "thank you for your support\n" +
                    "<b>https://www.patreon.com/feel_vam</b>\n\n" +
                    "</color>");
                UIDynamic helpTextfield = CreateTextField(helpText, true);
                helpTextfield.height = 300.0f;

                var btn = CreateButton("Go To Support", true);
                btn.button.onClick.AddListener(() =>
                {
                    Application.OpenURL("https://www.patreon.com/feel_vam");
                });

            }
            catch (Exception e)
            {
                SuperController.LogError("Exception caught: " + e);
            }
        }

        private void OnIsShowStrap(JSONStorableBool jb)
        {
            StrapObj.gameObject.SetActive(jb.val);
        }

        // Update is called with each rendered frame by Unity
        void Update()
        {
            if (_initLoops < _maxInitLoops)
            {
                _initLoops++;
                FirstInit();
            }
            else
            {
                if (_initLoops == 1001)
                {
                    SuperController.LogError("VamGirlExperience Load Failure " + _initLoops);
                    _initLoops += 1;
                }
            }
        }

        private void FirstInit()
        {
            ObjectRoot = getObjectRoot(containingAtom.reParentObject, "scooter_helmet");

            if (ObjectRoot != null)
            {
                StrapObj = getChildRoot(ObjectRoot, "Strap");

                _initLoops += _maxInitLoops + 100;
            }
        }

        void OnDestroy()
        {
            
        }

        private Transform getObjectRoot(Transform parent, string rootName)
        {
            foreach (Transform child in parent)
            {
                if (child.name.Contains(rootName))
                {
                    return child;
                }
                else
                {
                    Transform childSearch = getObjectRoot(child, rootName);
                    if (childSearch != null) return childSearch;
                }
            }

            return null;
        }

        private Transform getChildRoot(Transform parent, string searchName)
        {
            foreach (Transform child in parent)
            {
                if (child.name == searchName)
                {

                    return child;
                }
                else
                {
                    Transform childSearch = getChildRoot(child, searchName);
                    if (childSearch != null) return childSearch;
                }
            }

            return null;
        }

    }

}